@@ -342,10 +342,11 @@ class Lib:
             nltk.download('stopwords')
             stopwords = nltk.corpus.stopwords.words(language_or_stopwords_list)
         words = word_tokenize(document)
+        clean_words = []
         for w in words:
-            if w in stopwords:
-                words.remove(w)
-        return ' '.join(words)
+            if w not in stopwords:
+                clean_words.append(w)
+        return ' '.join(clean_words)
 
     @staticmethod
     def no_accent(string_in):
